<?php

namespace Teknisa\SM\Util\Procedure;

use Doctrine\DBAL\Connection;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class FctFaturaContrato {
    
    const NOME = "FCT_FATURA_CONTRATO";
    private $connection;
    
    public function __construct(Connection $connection) {
        $this->connection = $connection;
    }
    
    /**
     * Executa a procedure FCT_FATURA_CONTRATO.
     * 
     * @param integer $nrorg
     * @param string  $nrseqcontrato
     * @param string  $nrparcnegocio
     * @param string  $operador
     * @param string  $dtInicial
     * @param string  $dtFinal
     * @param string  $nrvencprevcont
     * @param string  $nrgrupofatura
     * 
     * @return string
     */
    public function executar($nrseqcontrato, $nrparcnegocio, $dtInicial, $dtFinal, $nrvencprevcont, $nrgrupofatura, $nrrateioitemvenc, $nrorg, $operador) {
        $procedure = new StoredProcedure($this->connection, self::NOME);
        
        $procedure->addParam(new Param("P_NRORG",            Param::PARAM_INPUT,  $nrorg,            Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param("P_NRSEQCONTRATO",    Param::PARAM_INPUT,  $nrseqcontrato,    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param("P_NRPARCNEGOCIO",    Param::PARAM_INPUT,  $nrparcnegocio,    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param("P_CDOPERINCLUSAO",   Param::PARAM_INPUT,  $operador,         Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param("P_DATAINI",          Param::PARAM_INPUT,  $dtInicial,        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param("P_DATAFIN",          Param::PARAM_INPUT,  $dtFinal,          Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param("P_NRVENCPREVCONT",   Param::PARAM_INPUT,  $nrvencprevcont,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param("P_NRGRUPOFATURA",    Param::PARAM_INPUT,  $nrgrupofatura,    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param("P_NRRATEIOITEMVENC", Param::PARAM_INPUT,  $nrrateioitemvenc, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param("P_RETORNO",          Param::PARAM_OUTPUT, null,              Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param("P_RETORNOERRO",      Param::PARAM_OUTPUT, null,              Param::PARAM_TYPE_STR));
        
        $resultado = $procedure->execute();
        
        return $resultado["P_RETORNOERRO"];


    }
    
}

?>
